=== modified file 'drizzled/base.h'
--- drizzled/base.h	2010-03-01 01:16:44 +0000
+++ drizzled/base.h	2010-03-29 20:16:08 +0000
@@ -506,6 +506,7 @@
 
 #define HA_VARCHAR_PACKLENGTH(field_length) ((field_length) < 256 ? 1 :2)
 
+
 } /* namespace drizzled */
 
 #endif /* DRIZZLED_BASE_H */

=== modified file 'drizzled/lock.cc'
--- drizzled/lock.cc	2010-03-05 03:08:42 +0000
+++ drizzled/lock.cc	2010-03-29 20:16:08 +0000
@@ -1048,9 +1048,12 @@
   session->global_read_lock= 0;
 }
 
-#define must_wait (global_read_lock &&                             \
-                   (is_not_commit ||                               \
-                    global_read_lock_blocks_commit))
+static inline bool must_wait(bool is_not_commit)
+{
+  return (global_read_lock &&
+          (is_not_commit ||
+          global_read_lock_blocks_commit));
+}
 
 bool wait_if_global_read_lock(Session *session, bool abort_on_refresh,
                               bool is_not_commit)
@@ -1066,7 +1069,7 @@
   safe_mutex_assert_not_owner(&LOCK_open);
 
   (void) pthread_mutex_lock(&LOCK_global_read_lock);
-  if ((need_exit_cond= must_wait))
+  if ((need_exit_cond= must_wait(is_not_commit)))
   {
     if (session->global_read_lock)		// This thread had the read locks
     {
@@ -1083,7 +1086,7 @@
     }
     old_message=session->enter_cond(&COND_global_read_lock, &LOCK_global_read_lock,
 				"Waiting for release of readlock");
-    while (must_wait && ! session->killed &&
+    while (must_wait(is_not_commit) && ! session->killed &&
 	   (!abort_on_refresh || session->version == refresh_version))
     {
       (void) pthread_cond_wait(&COND_global_read_lock, &LOCK_global_read_lock);

=== modified file 'drizzled/select_export.h'
--- drizzled/select_export.h	2010-02-04 08:14:46 +0000
+++ drizzled/select_export.h	2010-03-29 20:16:08 +0000
@@ -57,6 +57,18 @@
   ~select_export();
   int prepare(List<Item> &list, Select_Lex_Unit *u);
   bool send_data(List<Item> &items);
+private:
+  inline bool needs_escaping(char character, bool enclosed)
+  {
+    if ((character == escape_char) ||
+        (enclosed ? character == field_sep_char : character == field_term_char) ||
+        character == line_sep_char  ||
+        (character == 0))
+      return true;
+
+    return false;
+
+  }
 };
 
 } /* namespace drizzled */

=== modified file 'drizzled/session.cc'
--- drizzled/session.cc	2010-03-31 05:53:34 +0000
+++ drizzled/session.cc	2010-03-31 22:22:16 +0000
@@ -383,7 +383,7 @@
 
 Session::~Session()
 {
-  Session_CHECK_SENTRY(this);
+  this->checkSentry();
   add_to_status(&global_status_var, &status_var);
 
   if (client->isConnected())
@@ -470,7 +470,7 @@
 
 void Session::awake(Session::killed_state state_to_set)
 {
-  Session_CHECK_SENTRY(this);
+  this->checkSentry();
   safe_mutex_assert_owner(&LOCK_delete);
 
   killed= state_to_set;
@@ -1143,13 +1143,6 @@
   return 0;
 }
 
-
-#define NEED_ESCAPING(x) ((int) (unsigned char) (x) == escape_char    || \
-                          (enclosed ? (int) (unsigned char) (x) == field_sep_char      \
-                                    : (int) (unsigned char) (x) == field_term_char) || \
-                          (int) (unsigned char) (x) == line_sep_char  || \
-                          !(x))
-
 bool select_export::send_data(List<Item> &items)
 {
   char buff[MAX_FIELD_WIDTH],null_buff[2],space[MAX_FIELD_WIDTH];
@@ -1266,11 +1259,11 @@
             assert before the loop makes that sure.
           */
 
-          if ((NEED_ESCAPING(*pos) ||
+          if ((needs_escaping(*pos, enclosed) ||
                (check_second_byte &&
                 my_mbcharlen(character_set_client, (unsigned char) *pos) == 2 &&
                 pos + 1 < end &&
-                NEED_ESCAPING(pos[1]))) &&
+                needs_escaping(pos[1], enclosed))) &&
               /*
                 Don't escape field_term_char by doubling - doubling is only
                 valid for ENCLOSED BY characters:

=== modified file 'drizzled/session.h'
--- drizzled/session.h	2010-03-31 05:53:34 +0000
+++ drizzled/session.h	2010-03-31 22:22:16 +0000
@@ -142,8 +142,6 @@
 #define Session_SENTRY_MAGIC 0xfeedd1ff
 #define Session_SENTRY_GONE  0xdeadbeef
 
-#define Session_CHECK_SENTRY(session) assert(session->dbug_sentry == Session_SENTRY_MAGIC)
-
 struct system_variables
 {
   system_variables() {};
@@ -465,6 +463,11 @@
 
 private:
   SecurityContext security_ctx;
+
+  inline void checkSentry() const
+  {
+    assert(this->dbug_sentry == Session_SENTRY_MAGIC);
+  }
 public:
   const SecurityContext& getSecurityContext() const
   {

=== modified file 'drizzled/statement/alter_table.cc'
--- drizzled/statement/alter_table.cc	2010-03-31 05:53:34 +0000
+++ drizzled/statement/alter_table.cc	2010-03-31 22:22:16 +0000
@@ -91,7 +91,7 @@
     if (create_info.db_type == NULL)
     {
       my_error(ER_UNKNOWN_STORAGE_ENGINE, MYF(0), 
-               create_table_message.name().c_str());
+               create_table_message.engine().name().c_str());
 
       return true;
     }

=== modified file 'drizzled/tzfile.h'
--- drizzled/tzfile.h	2010-02-04 08:14:46 +0000
+++ drizzled/tzfile.h	2010-03-29 20:16:08 +0000
@@ -144,8 +144,6 @@
   that will probably do.
 */
 
-#define isleap(y) (((y) % 4) == 0 && (((y) % 100) != 0 || ((y) % 400) == 0))
-
 } /* namespace drizzled */
 
 #endif /* DRIZZLED_TZFILE_H */

=== modified file 'drizzled/tztime.cc'
--- drizzled/tztime.cc	2010-02-04 08:14:46 +0000
+++ drizzled/tztime.cc	2010-03-29 20:16:08 +0000
@@ -116,8 +116,15 @@
   DAYS_PER_NYEAR, DAYS_PER_LYEAR
 };
 
-#define LEAPS_THRU_END_OF(y)  ((y) / 4 - (y) / 100 + (y) / 400)
+static inline int leaps_thru_end_of(int year)
+{
+  return ((year) / 4 - (year) / 100 + (year) / 400);
+}
 
+static inline bool isleap(int year)
+{
+  return (((year) % 4) == 0 && (((year) % 100) != 0 || ((year) % 400) == 0));
+}
 
 /*
   Converts time from time_t representation (seconds in UTC since Epoch)
@@ -181,8 +188,8 @@
     if (days < 0)
       newy--;
     days-= (newy - y) * DAYS_PER_NYEAR +
-           LEAPS_THRU_END_OF(newy - 1) -
-           LEAPS_THRU_END_OF(y - 1);
+           leaps_thru_end_of(newy - 1) -
+           leaps_thru_end_of(y - 1);
     y= newy;
   }
   tmp->year= y;
@@ -388,15 +395,15 @@
   */
   assert(mon > 0 && mon < 13);
   long days= year * DAYS_PER_NYEAR - EPOCH_YEAR * DAYS_PER_NYEAR +
-             LEAPS_THRU_END_OF(year - 1) -
-             LEAPS_THRU_END_OF(EPOCH_YEAR - 1);
+             leaps_thru_end_of(year - 1) -
+             leaps_thru_end_of(EPOCH_YEAR - 1);
   days+= mon_starts[isleap(year)][mon - 1];
 #else
   long norm_month= (mon - 1) % MONS_PER_YEAR;
   long a_year= year + (mon - 1)/MONS_PER_YEAR - (int)(norm_month < 0);
   long days= a_year * DAYS_PER_NYEAR - EPOCH_YEAR * DAYS_PER_NYEAR +
-             LEAPS_THRU_END_OF(a_year - 1) -
-             LEAPS_THRU_END_OF(EPOCH_YEAR - 1);
+             leaps_thru_end_of(a_year - 1) -
+             leaps_thru_end_of(EPOCH_YEAR - 1);
   days+= mon_starts[isleap(a_year)]
                     [norm_month + (norm_month < 0 ? MONS_PER_YEAR : 0)];
 #endif

